MultiPartVal

Enum MultiPartVal 

pub enum MultiPartVal {
    A(String),
    C,
    P(i128),
    S(i128, Option<String>),
    T(i128),
    U(i128),
}
Parameters used in M486 Commands

Variants



A(String)

A Integrity check used to assert this name is equal to be equivalent embedded stl file name.



C

C ; Cancel the current object (use with care!)



P(i128)

P10 ; Cancel object with index 10 (the 11th object)



S(i128, Option<String>)

M486 S3 ; Indicate that the 4th object is starting now M486 S3 A“cube copy 3“ ; Indicate that the 4th object is starting now and name it S-1 ; Indicate a non-object, purge tower, or other global feature



T(i128)

T12 ; Total of 12 objects (otherwise the firmware must count)



U(i128)

U2 ; Un-cancel object with index 2 (the 3rd object)